@@ -1,6 +1,6 @@
 import yaml
 
-from pydmt.utils.filesystem import touch
+from pydmt.utils.filesystem import mkdir_touch
 
 from pydmt.builders.one_source_one_target import OneSourceOneTarget
 
@@ -9,4 +9,4 @@ class YamlValidate(OneSourceOneTarget):
     def build(self):
         with open(self.source, "rt") as input_handle:
             yaml.load(input_handle, yaml.SafeLoader)
-        touch(self.target)
+        mkdir_touch(self.target)
