@@ -6,12 +6,17 @@ import pylogconf.core
 from pytconf import register_endpoint, register_main, config_arg_parse_and_launch
 
 from pydmt.features.documentation import Documentation
-from pydmt.core.pydmt import PyDMT
 from pydmt.features.templating import Templating
+from pydmt.features.yaml import Yaml
+from pydmt.core.pydmt import PyDMT
 from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
 
 
 def add_to_path():
+    """
+    This adds to PYTHONPATH various paths we need
+    If you disable this then templates would not be able to find things like 'config/python.py'
+    """
     add_import_of_cwd = True
     add_import_of_home = True
     add_import_of_shared = True
@@ -32,18 +37,17 @@ def add_to_path():
     description="Build the project",
 )
 def build():
-    # add_to_path()
+    add_to_path()
 
     pylogconf.core.setup()
     p = PyDMT()
 
-    # add templating support
     f = Templating()
     f.setup(p)
-
-    # add sphinx support
     f = Documentation()
     f.setup(p)
+    f = Yaml()
+    f.setup(p)
 
     stats = p.build_all()
     sys.exit(stats.get_os_error_code())
